pub struct InputImage<'a> { /* private fields */ }Expand description
A reference to image bytes with the image size attached.
Can either be constructed directly using a slice of RGBRGBRGB… image bytes with
InputImage::from_bytes, or, if the image feature is enabled, with InputImage::try_from
from image::ImageBuffer.
Validates the parameters during construction, see InputImageError.
Implementations
Sourceimpl InputImage<'_>
impl InputImage<'_>
Sourcepub fn from_bytes(
width: u16,
height: u16,
buf: &[u8],
) -> Result<InputImage<'_>, InputImageError>
pub fn from_bytes( width: u16, height: u16, buf: &[u8], ) -> Result<InputImage<'_>, InputImageError>
Creates an InputImage from raw byte slice in RGBRGBRGB… format. The bytes
are assumed to be in sRGB. InputImage only holds a reference to the image bytes,
so it’s cheap to create.